@@ -17,7 +17,7 @@ use Sys::Hostname;
 # Do not simply export all your public functions/methods/constants.
 @EXPORT = qw();
 @EXPORT_OK = qw($_openssl);
-$VERSION = '0.32';
+$VERSION = '0.34';
 
 
 # Preloaded methods go here.
@@ -71,7 +71,7 @@ sub DESTROY
 
     foreach my $file (keys %{$self->{_tmpfiles}})
       {
-	#unlink $file;
+	unlink $file;
       }
 
     my $dir = $self->caDir();
@@ -150,8 +150,8 @@ sub mppFile
 	      {
 		my $expr = $1;
 		
-		$expr =~ s/%{([A-Za-z0-9_\.]+)}/\$vars->{$1}/g;
-	        warn "EXPR: \"".$expr."\"\n";
+		$expr =~ s/%{([A-Za-z0-9_\.]+)}/"\$vars->{\"$1\"}"/eg;
+		
 		my $result = eval $expr;
 		$self->die("$@") if $@;
 		$ctx->push($result);
@@ -231,7 +231,7 @@ default_ca      = $self->{name}
 
 [ $self->{name} ]
 
-dir                     = $self->{dir}/csp/\${csp::ca}
+dir                     = \${csp::home}/csp/\${csp::ca}
 certs                   = \$dir/certs
 database                = \$dir/index.txt
 certificate             = \$dir/ca.crt
@@ -949,7 +949,7 @@ sub revoke
     $self->die("CA key must have a password")
       unless defined($args->{capass});
 
-    $self->{openssl}->cmd('ca',"-passin pass:$args->{capass} -batch -revoke $file",$args);
+    $self->{openssl}->cmd('ca',"-passin pass:$args->{capass} -batch -updatedb -revoke $file",$args);
   }
 
 sub _time
@@ -1286,7 +1286,7 @@ sub parse_date
 
     $y += 100;
     my $wday = Day_of_Week($y+1999,$mon,$mday);
-    my @date = ($s,$m,$h,$mday,$mon,$y,$wday,0);
+    my @date = ($s,$m,$h,$mday,$mon-1,$y,$wday,0);
     \@date;
   }
 
